import inspect
import os
from typing import List


def includes() -> str:
    """Provides access to assorted C++ headers for downstream packages.

    Returns:
        str: Path to a directory containing lots of header files.
    """
    dirname = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
    return os.path.join(dirname, "include")



import os
from assorthead import includes

__author__ = "Aaron Lun"
__copyright__ = "Aaron Lun"
__license__ = "MIT"


def test_includes():
    out = includes()
    assert isinstance(out, str)
    assert os.path.isdir(os.path.join(out, "annoy"))
    assert os.path.isdir(os.path.join(out, "byteme"))
